@@ -1,14 +1,14 @@
 use 5.014002;
 package Aniki {
     use namespace::sweep;
-    use Mouse;
+    use Mouse v2.4.5;
     use Module::Load ();
     use Aniki::Row;
     use Aniki::Collection;
     use Aniki::Schema;
     use Aniki::QueryBuilder;
 
-    our $VERSION = '0.02_08';
+    our $VERSION = '0.02_09';
 
     use SQL::Maker::SQLType qw/sql_type/;
     use DBIx::Sunny;
@@ -83,12 +83,8 @@ package Aniki {
         if (my $schema_class = $args{schema}) {
             Module::Load::load($schema_class);
 
-            my $schema        = Aniki::Schema->new(schema_class => $schema_class);
-            my $driver        = $class->_database2driver($schema->database);
-            my $query_builder = Aniki::QueryBuilder->new(driver => $driver, strict => $class->use_strict_query_builder);
-
-            $class->meta->add_method(schema        => sub { $schema        });
-            $class->meta->add_method(query_builder => sub { $query_builder });
+            my $schema = Aniki::Schema->new(schema_class => $schema_class);
+            $class->meta->add_method(schema => sub { $schema });
         }
         if (my $filter_class = $args{filter}) {
             Module::Load::load($filter_class);
@@ -97,6 +93,16 @@ package Aniki {
             $class->meta->add_method(filter => sub { $filter });
         }
 
+        {
+            my $query_builder_class = 'Aniki::QueryBuilder';
+            if ($args{query_builder}) {
+                Module::Load::load($args{query_builder});
+                $query_builder_class = $args{query_builder};
+            }
+            my $driver        = $class->_database2driver($class->schema->database);
+            my $query_builder = $query_builder_class->new(driver => $driver, strict => $class->use_strict_query_builder);
+            $class->meta->add_method(query_builder => sub { $query_builder });
+        }
         {
             my $row_class = 'Aniki::Row';
             if ($args{row}) {
@@ -295,16 +301,31 @@ package Aniki {
         my ($self, $table_name, $relay, $rows) = @_;
         return unless @$rows;
 
+        $relay = [$relay] if ref $relay eq 'HASH';
+
         my $relationships = $self->schema->get_relationships($table_name);
         for my $key (@$relay) {
-            my $relationship = $relationships->get_relationship($key);
-            unless ($relationship) {
-                croak "'$key' is not defined as relationship. (maybe possible typo?)";
+            if (ref $key && ref $key eq 'HASH') {
+                my %relay = %$key;
+                for my $key (keys %relay) {
+                    $self->_attach_relay_data($relationships, $rows, $key, $relay{$key});
+                }
+            }
+            else {
+                $self->_attach_relay_data($relationships, $rows, $key, []);
             }
-            $relationship->fetcher($self)->execute($rows);
         }
     }
 
+    sub _attach_relay_data {
+        my ($self, $relationships, $rows, $key, $relay) = @_;
+        my $relationship = $relationships->get_relationship($key);
+        unless ($relationship) {
+            croak "'$key' is not defined as relationship. (maybe possible typo?)";
+        }
+        $relationship->fetcher($self)->execute($rows, $relay);
+    }
+
     sub select_named {
         my ($self, $sql, $bind, $opt) = @_;
         return $self->select_by_sql(bind_named($sql, $bind), $opt);
@@ -316,6 +337,7 @@ package Aniki {
 
         my $table_name = exists $opt->{table_name}  ? $opt->{table_name} : $self->_guess_table_name($sql);
         my $relay      = exists $opt->{relay}       ? $opt->{relay}      : [];
+           $relay      = [$relay] if ref $relay eq 'HASH';
 
         my $relay_enabled_fg = @$relay && !$self->suppress_row_objects;
         if ($relay_enabled_fg) {
@@ -536,7 +558,7 @@ Aniki - The ORM as our great brother.
     };
 
     package MyProj::DB {
-        use Mouse;
+        use Mouse v2.4.5;
         extends qw/Aniki/;
 
         __PACKAGE__->setup(
